Module memorystore
autocore_
std
3.3.38
Module memorystore
Module Items
Structs
In autocore_
std::
fb
autocore_std
::
fb
Module
memorystore
Structs

Memory
Store
Read
Function block for reading a key from the MemoryStore.
Memory
Store
Write
Function block for writing a key to the MemoryStore.