#[repr(u16)]pub enum CommandStatus {
Init = 1,
Idle = 10,
Executing = 20,
Done = 100,
Error = 900,
}Expand description
Status of the command interface, written by the control program.
These values are written to command_status in CommandInterfaceView.
Variants
Init = 1
Initial state before first scan.
Idle = 10
Ready to accept a new command.
Executing = 20
A command is currently being processed.
Done = 100
Command completed successfully. Result is available in command_result.
Error = 900
Command failed. The control program may place an error code in command_result.
Implementations