Module iface

Module iface 

Interface protocols for communication between control programs and external sources.

Interface Protocols

Reusable interface protocols for communication between control programs and external sources (UI, HMI, other modules) via shared memory.

Unlike function blocks which are cyclical IEC 61131-3 primitives, these are stateful protocol handlers that manage handshake sequences over shared memory fields.

Available Interfaces

InterfaceDescription
[CommandInterface]Request/acknowledge command handshake (CANopen/EtherCAT style)

Structs

CommandInterface
Command Interface function block.
CommandInterfaceView
View struct for mapping command interface signals to GlobalMemory fields.

Enums

CommandRequest
Request codes written by the external source (UI/HMI).
CommandStatus
Status of the command interface, written by the control program.